==> istio-model-v1beta1-6.3.1-sources.jar: io/fabric8/istio/api/networking/v1beta1/VirtualServiceListFluent.java <==
package io.fabric8.istio.api.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface VirtualServiceListFluent<A extends VirtualServiceListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,VirtualService item);
  public A setToItems(Integer index,VirtualService item);
  public A addToItems(io.fabric8.istio.api.networking.v1beta1.VirtualService... items);
  public A addAllToItems(Collection<VirtualService> items);
  public A removeFromItems(io.fabric8.istio.api.networking.v1beta1.VirtualService... items);
  public A removeAllFromItems(Collection<VirtualService> items);
  public A removeMatchingFromItems(Predicate<VirtualServiceBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<VirtualService> getItems();
  public List<VirtualService> buildItems();
  public VirtualService buildItem(Integer index);
  public VirtualService buildFirstItem();
  public VirtualService buildLastItem();
  public VirtualService buildMatchingItem(Predicate<VirtualServiceBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<VirtualServiceBuilder> predicate);
  public A withItems(List<VirtualService> items);
  public A withItems(io.fabric8.istio.api.networking.v1beta1.VirtualService... items);
  public Boolean hasItems();
  public VirtualServiceListFluent.ItemsNested<A> addNewItem();
  public VirtualServiceListFluent.ItemsNested<A> addNewItemLike(VirtualService item);
  public VirtualServiceListFluent.ItemsNested<A> setNewItemLike(Integer index,VirtualService item);
  public VirtualServiceListFluent.ItemsNested<A> editItem(Integer index);
  public VirtualServiceListFluent.ItemsNested<A> editFirstItem();
  public VirtualServiceListFluent.ItemsNested<A> editLastItem();
  public VirtualServiceListFluent.ItemsNested<A> editMatchingItem(Predicate<VirtualServiceBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,VirtualServiceFluent<VirtualServiceListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> istio-model-v1beta1-6.7.1-sources.jar: io/fabric8/istio/api/networking/v1beta1/VirtualServiceListFluent.java <==
package io.fabric8.istio.api.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface VirtualServiceListFluent<A extends VirtualServiceListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,VirtualService item);
  public A setToItems(int index,VirtualService item);
  public A addToItems(io.fabric8.istio.api.networking.v1beta1.VirtualService... items);
  public A addAllToItems(Collection<VirtualService> items);
  public A removeFromItems(io.fabric8.istio.api.networking.v1beta1.VirtualService... items);
  public A removeAllFromItems(Collection<VirtualService> items);
  public A removeMatchingFromItems(Predicate<VirtualServiceBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<VirtualService> getItems();
  public List<VirtualService> buildItems();
  public VirtualService buildItem(int index);
  public VirtualService buildFirstItem();
  public VirtualService buildLastItem();
  public VirtualService buildMatchingItem(Predicate<VirtualServiceBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<VirtualServiceBuilder> predicate);
  public A withItems(List<VirtualService> items);
  public A withItems(io.fabric8.istio.api.networking.v1beta1.VirtualService... items);
  public Boolean hasItems();
  public VirtualServiceListFluent.ItemsNested<A> addNewItem();
  public VirtualServiceListFluent.ItemsNested<A> addNewItemLike(VirtualService item);
  public VirtualServiceListFluent.ItemsNested<A> setNewItemLike(int index,VirtualService item);
  public VirtualServiceListFluent.ItemsNested<A> editItem(int index);
  public VirtualServiceListFluent.ItemsNested<A> editFirstItem();
  public VirtualServiceListFluent.ItemsNested<A> editLastItem();
  public VirtualServiceListFluent.ItemsNested<A> editMatchingItem(Predicate<VirtualServiceBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,VirtualServiceFluent<VirtualServiceListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
